@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -51,9 +52,7 @@
 #include <comphelper/processfactory.hxx>
 #include <tools/debug.hxx>
 #include <bf_svtools/zforlist.hxx>		// IsNumberFormat
-#ifndef _LEGACYBINFILTERMGR_HXX
 #include <legacysmgr/legacy_binfilters_smgr.hxx>	//STRIP002 
-#endif
 namespace binfilter {
 using namespace ::com::sun::star;
 
@@ -1087,3 +1086,5 @@ DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	if ( pServDesc && rDesc == *pServDesc )
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
