@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -42,6 +43,7 @@
 #include <bf_sfx2/app.hxx>
 #include <unotools/configitem.hxx>
 #include <comphelper/types.hxx>
+#include <sal/macros.h>
 
 #include <sot/formats.hxx>
 #define SOT_FORMATSTR_ID_STARCALC_30 SOT_FORMATSTR_ID_STARCALC
@@ -91,13 +93,14 @@ static const sal_Char __FAR_DATA pFilterRtf[]		= "Rich Text Format (StarCalc)";
 
 /*N*/ class ScLibOptions : public ::utl::ConfigItem
 /*N*/ {
-/*N*/ 	BOOL		bWK3Flag;
+/*N*/ 	BOOL	bWK3Flag;
 /*N*/
 /*N*/ public:
-/*N*/ 				ScLibOptions();
-/*N*/ 	BOOL		GetWK3Flag() const			{ return bWK3Flag; }
-    virtual void                Notify( const ::com::sun::star::uno::Sequence< rtl::OUString >& aPropertyNames );
-    virtual void                Commit();
+/*N*/ 			ScLibOptions();
+/*N*/ 	BOOL	GetWK3Flag() const	{ return bWK3Flag; }
+
+        virtual void    Notify( const ::com::sun::star::uno::Sequence< rtl::OUString >& aPropertyNames );
+        virtual void    Commit();
 
 /*N*/ };
 
@@ -108,8 +111,8 @@ void ScLibOptions::Commit() {}
 #define ENTRYSTR_WK3			"WK3"
 
 /*N*/ ScLibOptions::ScLibOptions() :
-/*N*/ 	ConfigItem( ::rtl::OUString::createFromAscii( CFGPATH_LIBFILTER ) ),
-/*N*/ 	bWK3Flag( FALSE )
+/*N*/ 	    ConfigItem( ::rtl::OUString::createFromAscii( CFGPATH_LIBFILTER ) ),
+/*N*/ 	    bWK3Flag( FALSE )
 /*N*/ {
 /*N*/ 	::com::sun::star::uno::Sequence<rtl::OUString> aNames(1);
 /*N*/ 	aNames[0] = ::rtl::OUString::createFromAscii( ENTRYSTR_WK3 );
@@ -514,7 +517,7 @@ BOOL lcl_IsAnyXMLFilter( const SfxFilter* pFilter )
 /*N*/ 			pSylk,
 /*N*/ 			pLotus2
 /*N*/ 			};
-/*N*/ 		const UINT16 nAnzMuster = sizeof(ppMuster) / sizeof(ppMuster[0]);
+/*N*/ 		const UINT16 nAnzMuster = SAL_N_ELEMENTS(ppMuster);
 /*N*/ #endif
 /*N*/
 /*N*/ 		const sal_Char* pFilterName[ nAnzMuster ] = 	// zugehoerige Filter
@@ -530,8 +533,6 @@ BOOL lcl_IsAnyXMLFilter( const SfxFilter* pFilter )
 /*N*/ 			pFilterLotus
 /*N*/ 			};
 /*N*/
-/*N*/ 		const UINT16 nByteMask = 0xFF;
-/*N*/
 /*N*/ 		// suchen Sie jetzt!
 /*N*/ 		// ... realisiert ueber 'Mustererkennung'
 /*N*/
@@ -651,3 +652,5 @@ BOOL lcl_IsAnyXMLFilter( const SfxFilter* pFilter )
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
