@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -66,9 +67,7 @@
 #include "attrib.hxx"
 #include "dbdocutl.hxx"
 #include "editable.hxx"
-#ifndef _LEGACYBINFILTERMGR_HXX
 #include <legacysmgr/legacy_binfilters_smgr.hxx>	//STRIP002 
-#endif
 namespace binfilter {
 using namespace ::com::sun::star;
 
@@ -566,3 +565,5 @@ SV_DECL_IMPL_REF(SbaSelectionList)
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
