@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,15 +26,9 @@
  *
  ************************************************************************/
 
-#ifndef _SFX_HRC //autogen
 #include <bf_sfx2/sfx.hrc>
-#endif
-#ifndef _SV_SALBTYPE_HRC //autogen
 #include <vcl/salbtype.hxx>
-#endif
-#ifndef INCLUDED_SVTOOLS_SYSLOCALE_HXX 
 #include <bf_svtools/syslocale.hxx>
-#endif
 
 #include "optsitem.hxx"
 #include "cfgids.hxx"
@@ -1122,3 +1117,5 @@ int SdOptionsPrintItem::operator==( const SfxPoolItem& rAttr ) const
 // ----------------------------------------------------------------------
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
