@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,31 +26,17 @@
  *
  ************************************************************************/
 
-#ifndef _COM_SUN_STAR_LANG_DISPOSEDEXCEPTION_HPP_
 #include <com/sun/star/lang/DisposedException.hpp>
-#endif
-#ifndef _COM_SUN_STAR_FRAME_XFRAME_HPP_
 #include <com/sun/star/frame/XFrame.hpp>
-#endif
-#ifndef _COM_SUN_STAR_UTIL_DATETIME_HPP_
 #include <com/sun/star/util/DateTime.hpp>
-#endif
-#ifndef _COM_SUN_STAR_BEANS_PROPERTYATTRIBUTE_HPP_
 #include <com/sun/star/beans/PropertyAttribute.hpp>
-#endif
-#ifndef _CPPUHELPER_INTERFACECONTAINER_HXX_
 #include <cppuhelper/interfacecontainer.hxx>
-#endif
-#ifndef _COM_SUN_STAR_IO_IOEXCEPTION_HPP_
 #include <com/sun/star/io/IOException.hpp>
-#endif
 
 #include <com/sun/star/xml/sax/XParser.hpp>
 #include <com/sun/star/document/XImporter.hpp>
 
-#ifndef _LEGACYBINFILTERMGR_HXX
 #include <legacysmgr/legacy_binfilters_smgr.hxx>
-#endif
 
 #include <tools/errcode.hxx>
 #include <bf_so3/svstor.hxx>
@@ -76,10 +63,9 @@
 #include "objshimp.hxx"
 
 #include <osl/mutex.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 namespace binfilter {
 
-using namespace vos;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::frame;
@@ -360,7 +346,7 @@ using namespace ::com::sun::star::frame;
 
 /*N*/ void SAL_CALL  SfxDocumentInfoObject::setFastPropertyValue(sal_Int32 nHandle, const ::com::sun::star::uno::Any& aValue) throw( ::com::sun::star::uno::RuntimeException )
 /*N*/ {
-/*N*/ 	::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/ 	SolarMutexGuard aGuard;
 /*N*/ 	sal_Bool bModified = sal_True;
 /*N*/
 /*N*/ 	if ( aValue.getValueType() == ::getCppuType((const ::rtl::OUString*)0) )
@@ -560,7 +546,7 @@ using namespace ::com::sun::star::frame;
 
 /*N*/ ::com::sun::star::uno::Any SAL_CALL  SfxDocumentInfoObject::getFastPropertyValue(sal_Int32 nHandle) throw( ::com::sun::star::uno::RuntimeException )
 /*N*/ {
-/*N*/ 	::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/ 	SolarMutexGuard aGuard;
 /*N*/ 	::com::sun::star::uno::Any aValue;
 /*N*/ 	if ( nHandle == WID_CONTENT_TYPE )
 /*N*/ 	{
@@ -711,7 +697,7 @@ using namespace ::com::sun::star::frame;
 
 /*N*/ sal_Int16 SAL_CALL  SfxDocumentInfoObject::getUserFieldCount() throw( ::com::sun::star::uno::RuntimeException )
 /*N*/ {
-/*N*/ 	::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/ 	SolarMutexGuard aGuard;
 /*N*/ 	return _pInfo->GetUserKeyCount();
 /*N*/ }
 
@@ -719,7 +705,7 @@ using namespace ::com::sun::star::frame;
 
 /*N*/ ::rtl::OUString SAL_CALL  SfxDocumentInfoObject::getUserFieldName(sal_Int16 nIndex) throw( ::com::sun::star::uno::RuntimeException )
 /*N*/ {
-/*N*/ 	::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/ 	SolarMutexGuard aGuard;
 /*N*/ 	if ( nIndex < _pInfo->GetUserKeyCount() )
 /*N*/ 		return _pInfo->GetUserKey( nIndex ).GetTitle();
 /*N*/ 	else
@@ -730,7 +716,7 @@ using namespace ::com::sun::star::frame;
 
 /*N*/ ::rtl::OUString SAL_CALL  SfxDocumentInfoObject::getUserFieldValue(sal_Int16 nIndex) throw( ::com::sun::star::uno::RuntimeException )
 /*N*/ {
-/*N*/ 	::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/ 	SolarMutexGuard aGuard;
 /*N*/ 	if ( nIndex < _pInfo->GetUserKeyCount() )
 /*N*/ 		return _pInfo->GetUserKey( nIndex ).GetWord();
 /*N*/ 	else
@@ -741,7 +727,7 @@ using namespace ::com::sun::star::frame;
 
 /*N*/ void  SAL_CALL SfxDocumentInfoObject::setUserFieldName(sal_Int16 nIndex, const ::rtl::OUString& aName ) throw( ::com::sun::star::uno::RuntimeException )
 /*N*/ {
-/*N*/ 	::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/ 	SolarMutexGuard aGuard;
 /*N*/ 	if ( nIndex < _pInfo->GetUserKeyCount() )
 /*N*/ 	{
 /*N*/ 		const SfxDocUserKey& rKey = _pInfo->GetUserKey( nIndex );
@@ -756,7 +742,7 @@ using namespace ::com::sun::star::frame;
 
 /*N*/ void SAL_CALL  SfxDocumentInfoObject::setUserFieldValue( sal_Int16 nIndex, const ::rtl::OUString& aValue ) throw( ::com::sun::star::uno::RuntimeException )
 /*N*/ {
-/*N*/ 	::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/ 	SolarMutexGuard aGuard;
 /*N*/ 	if ( nIndex < _pInfo->GetUserKeyCount() )
 /*N*/ 	{
 /*N*/ 		const SfxDocUserKey& rKey = _pInfo->GetUserKey( nIndex );
@@ -852,7 +838,7 @@ using namespace ::com::sun::star::frame;
 
 /*N*/ void SAL_CALL  SfxStandaloneDocumentInfoObject::loadFromURL(const ::rtl::OUString& aURL) throw( ::com::sun::star::io::IOException )
 /*N*/ {
-/*N*/ 	::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/ 	SolarMutexGuard aGuard;
 /*N*/ 	sal_Bool bOK = sal_False;
 /*N*/ 	String aName( aURL );
 /*N*/     SvStorage* pStorage = GetStorage_Impl( aName, sal_False );
@@ -914,7 +900,7 @@ using namespace ::com::sun::star::frame;
 
 /*N*/ void SAL_CALL  SfxStandaloneDocumentInfoObject::storeIntoURL(const ::rtl::OUString& aURL) throw( ::com::sun::star::io::IOException )
 /*N*/ {
-/*N*/ 	::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/ 	SolarMutexGuard aGuard;
 /*N*/ 	sal_Bool bOK = sal_False;
 /*N*/ 	String aName( aURL );
 /*N*/ 	SvStorage* pStor = GetStorage_Impl( aName, sal_True );
@@ -971,3 +957,5 @@ Reference< XInterface > SAL_CALL bf_BinaryDocInfo_createInstance(const Reference
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
