@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -29,110 +30,62 @@
 //	my own includes
 //________________________________________________________________________________________________________
 
-#ifndef _SFX_SFXBASEMODEL_HXX_
 #include <sfxbasemodel.hxx>
-#endif
 #include <bf_sfx2/app.hxx>
 
 //________________________________________________________________________________________________________
 //	include of other projects
 //________________________________________________________________________________________________________
 
-#ifndef _COM_SUN_STAR_VIEW_XPRINTJOB_HPP_
 #include <com/sun/star/view/XPrintJob.hpp>
-#endif
 
-#ifndef _COM_SUN_STAR_VIEW_XSELECTIONSUPPLIER_HPP_
 #include <com/sun/star/view/XSelectionSupplier.hpp>
-#endif
 
-#ifndef _COM_SUN_STAR_AWT_SIZE_HPP_
 #include <com/sun/star/awt/Size.hpp>
-#endif
 
-#ifndef _COM_SUN_STAR_LANG_DISPOSEDEXCEPTION_HPP_
 #include <com/sun/star/lang/DisposedException.hpp>
-#endif
 
-#ifndef _COM_SUN_STAR_LANG_ILLEGALARGUMENTEXCEPTION_HPP_
 #include <com/sun/star/lang/IllegalArgumentException.hpp>
-#endif
 
-#ifndef _COM_SUN_STAR_FRAME_ILLEGALARGUMENTIOEXCEPTION_HPP_
 #include <com/sun/star/frame/IllegalArgumentIOException.hpp>
-#endif
 
-#ifndef _COM_SUN_STAR_VIEW_PAPERFORMAT_HPP_
 #include <com/sun/star/view/PaperFormat.hpp>
-#endif
 
-#ifndef _COM_SUN_STAR_VIEW_PAPERORIENTATION_HPP_
 #include <com/sun/star/view/PaperOrientation.hpp>
-#endif
 
-#ifndef _CPPUHELPER_INTERFACECONTAINER_HXX_
 #include <cppuhelper/interfacecontainer.hxx>
-#endif
 
-#ifndef _UNOTOOLS_PROCESSFACTORY_HXX
 #include <comphelper/processfactory.hxx>
-#endif
 
-#ifndef _COM_SUN_STAR_CONTAINER_XINDEXCONTAINER_HPP_
 #include <com/sun/star/container/XIndexContainer.hpp>
-#endif
 
-#ifndef _COM_SUN_STAR_UCB_NAMECLASH_HPP_
 #include <com/sun/star/ucb/NameClash.hpp>
-#endif
 
-#ifndef _UNO_MAPPING_HXX_
 #include <uno/mapping.hxx>
-#endif
 
-#ifndef _SFXITEMSET_HXX
 #include <bf_svtools/itemset.hxx>
-#endif
 
-#ifndef _SFXSTRITEM_HXX
 #include <bf_svtools/stritem.hxx>
-#endif
 
-#ifndef _SFXINTITEM_HXX
 #include <bf_svtools/intitem.hxx>
-#endif
 
-#ifndef _SFXENUMITEM_HXX
 #include <bf_svtools/eitem.hxx>
-#endif
 
 #include "bf_basic/sbx.hxx"
 
-#ifndef _OSL_FILE_HXX_
 #include <osl/file.hxx>
-#endif
 
-#ifndef _THREAD_HXX_
 #include <osl/thread.hxx>
-#endif
 
-#ifndef _URLOBJ_HXX_
 #include <tools/urlobj.hxx>
-#endif
 
-#ifndef _UNOTOOLS_TEMPFILE_HXX_
 #include <unotools/tempfile.hxx>
-#endif
 
-#ifndef _UNOTOOLS_LOCALFILEHELPER_HXX_
 #include <unotools/localfilehelper.hxx>
-#endif
 
-#ifndef _UCBHELPER_CONTENT_HXX
 #include <ucbhelper/content.hxx>
-#endif
 
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 #include <vcl/salctype.hxx>
 
 //________________________________________________________________________________________________________
@@ -141,63 +94,37 @@
 
 #include "appuno.hxx"
 
-#ifndef _SFX_OBJSHIMP_HXX
 #include <objshimp.hxx>
-#endif
 
 
-#ifndef _SFXDOCFILE_HXX
 #include <docfile.hxx>
-#endif
 
-#ifndef _SFXREQUEST_HXX
 #include <request.hxx>
-#endif
 
-#ifndef _SFX_OBJUNO_HXX
 #include <objuno.hxx>
-#endif
 
-#ifndef _SFX_PRINTER_HXX
 #include <printer.hxx>
-#endif
 
-#ifndef _SFXEVENT_HXX
 #include <event.hxx>
-#endif
 
-#ifndef _SFX_EVENTSUPPLIER_HXX_
 #include <eventsupplier.hxx>
-#endif
 
-#ifndef _SFX_EVENTCONF_HXX
 #include <evntconf.hxx>
-#endif
 
-#ifndef _SFX_INTERNO_HXX
 #include <interno.hxx>
-#endif
 
-#ifndef _SFX_HRC
 #include "sfx.hrc"
-#endif
 
 #include "openflag.hxx"
 #include "appdata.hxx"
 #include "docfac.hxx"
 #include "fcontnr.hxx"
 
-#ifndef _LEGACYBINFILTERMGR_HXX
 #include <legacysmgr/legacy_binfilters_smgr.hxx>	//STRIP002
-#endif
 
-#ifndef _CPPUHELPER_TYPEPROVIDER_HXX_
 #include <cppuhelper/typeprovider.hxx>
-#endif
 
-#ifndef _BASMGR_HXX
 #include "bf_basic/basmgr.hxx"
-#endif
 
 namespace binfilter {
 
@@ -480,7 +407,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 
 /*N*/ REFERENCE< XNAMECONTAINER > SAL_CALL SfxBaseModel::getLibraryContainer() throw( RUNTIMEEXCEPTION )
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -501,7 +428,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ 	const OUSTRING& ExternalSourceURL, const OUSTRING& LinkTargetURL )
 /*N*/ 		throw(ELEMENTEXISTEXCEPTION, RUNTIMEEXCEPTION)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -520,7 +447,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ 	const OUSTRING& Language, const OUSTRING& Source )
 /*N*/ 		throw( NOSUCHELEMENTEXCEPTION, RUNTIMEEXCEPTION)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -539,7 +466,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ 	const ::com::sun::star::uno::Sequence< sal_Int8 >& Data )
 /*N*/ 		throw(NOSUCHELEMENTEXCEPTION, RUNTIMEEXCEPTION)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -573,7 +500,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
         }
     }
 */
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -586,7 +513,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 
 /*N*/ void SAL_CALL SfxBaseModel::setParent(const REFERENCE< XINTERFACE >& Parent) throw(NOSUPPORTEXCEPTION, RUNTIMEEXCEPTION)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( Parent.is() && getParent().is() )
 /*N*/ 		// only set parent when no parent is available
 /*N*/ 		throw NOSUPPORTEXCEPTION();
@@ -602,7 +529,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 
 /*N*/ void SAL_CALL SfxBaseModel::dispose() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/
 /*N*/ 	// object already disposed?
 /*N*/ 	if ( impl_isDisposed() )
@@ -670,7 +597,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/     throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		return;
 /*N*/
@@ -685,7 +612,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/     throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		return;
 /*N*/
@@ -699,7 +626,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ REFERENCE< XDOCUMENTINFO > SAL_CALL SfxBaseModel::getDocumentInfo() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -716,7 +643,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ void SAL_CALL SfxBaseModel::disposing( const EVENTOBJECT& aObject )
 /*N*/     throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		return;
 /*N*/
@@ -740,7 +667,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ 												const	SEQUENCE< PROPERTYVALUE >&	rArgs	)
 /*N*/     throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -803,7 +730,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 
 /*N*/ OUSTRING SAL_CALL SfxBaseModel::getURL() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -816,7 +743,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 
 /*N*/ SEQUENCE< PROPERTYVALUE > SAL_CALL SfxBaseModel::getArgs() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -892,7 +819,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ void SAL_CALL SfxBaseModel::connectController( const REFERENCE< XCONTROLLER >& xController )
 /*N*/     throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -910,7 +837,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 
 /*N*/ void SAL_CALL SfxBaseModel::disconnectController( const REFERENCE< XCONTROLLER >& xController ) throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -940,7 +867,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 
 /*N*/ void SAL_CALL SfxBaseModel::lockControllers() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/ 	++m_pData->m_nControllerLockCount ;
@@ -952,7 +879,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 
 /*N*/ void SAL_CALL SfxBaseModel::unlockControllers() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/ 	--m_pData->m_nControllerLockCount ;
@@ -964,7 +891,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 
 /*N*/ sal_Bool SAL_CALL SfxBaseModel::hasControllersLocked() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/ 	return ( m_pData->m_nControllerLockCount != 0 ) ;
@@ -977,7 +904,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ REFERENCE< XCONTROLLER > SAL_CALL SfxBaseModel::getCurrentController() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -997,7 +924,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/         throw (::com::sun::star::container::NoSuchElementException, ::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1011,7 +938,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ REFERENCE< XINTERFACE > SAL_CALL SfxBaseModel::getCurrentSelection() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1042,7 +969,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ sal_Bool SAL_CALL SfxBaseModel::isModified() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1057,7 +984,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/         throw (::com::sun::star::beans::PropertyVetoException, ::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1072,7 +999,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ void SAL_CALL SfxBaseModel::addModifyListener(const REFERENCE< XMODIFYLISTENER >& xListener) throw( RUNTIMEEXCEPTION )
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		return;
 /*N*/
@@ -1086,7 +1013,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ void SAL_CALL SfxBaseModel::removeModifyListener(const REFERENCE< XMODIFYLISTENER >& xListener) throw( RUNTIMEEXCEPTION )
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		return;
 /*N*/
@@ -1099,7 +1026,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 
 /*N*/ void SAL_CALL SfxBaseModel::close( sal_Bool bDeliverOwnership ) throw (CLOSEVETOEXCEPTION, RUNTIMEEXCEPTION)
 /*N*/ {
-/*N*/ 	::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/ 	SolarMutexGuard aGuard;
 /*N*/ 	if ( !m_pData || m_pData->m_bClosed || m_pData->m_bClosing )
 /*N*/ 		return;
 /*N*/
@@ -1155,7 +1082,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ void SAL_CALL SfxBaseModel::addCloseListener( const REFERENCE< XCLOSELISTENER >& xListener ) throw (RUNTIMEEXCEPTION)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		return;
 /*N*/
@@ -1169,7 +1096,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ void SAL_CALL SfxBaseModel::removeCloseListener( const REFERENCE< XCLOSELISTENER >& xListener ) throw (RUNTIMEEXCEPTION)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		return;
 /*N*/
@@ -1191,7 +1118,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ sal_Bool SAL_CALL SfxBaseModel::hasLocation() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1205,7 +1132,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ OUSTRING SAL_CALL SfxBaseModel::getLocation() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1219,7 +1146,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ sal_Bool SAL_CALL SfxBaseModel::isReadonly() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1233,7 +1160,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ void SAL_CALL SfxBaseModel::store() throw (::com::sun::star::io::IOException, ::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1258,7 +1185,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/         throw (::com::sun::star::io::IOException, ::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1281,7 +1208,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/         throw (::com::sun::star::io::IOException, ::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1302,7 +1229,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ 			   ::com::sun::star::uno::Exception)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1336,7 +1263,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ 			   ::com::sun::star::uno::Exception)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1426,7 +1353,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ REFERENCE< XNAMEREPLACE > SAL_CALL SfxBaseModel::getEvents() throw( RUNTIMEEXCEPTION )
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1445,7 +1372,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ void SAL_CALL SfxBaseModel::addEventListener( const REFERENCE< XDOCEVENTLISTENER >& aListener ) throw( RUNTIMEEXCEPTION )
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		return;
 /*N*/
@@ -1459,7 +1386,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ void SAL_CALL SfxBaseModel::removeEventListener( const REFERENCE< XDOCEVENTLISTENER >& aListener ) throw( RUNTIMEEXCEPTION )
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		return;
 /*N*/
@@ -1548,7 +1475,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ {
 /*N*/ 	// object already disposed?
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		return;
 /*N*/
@@ -1655,7 +1582,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ REFERENCE < XINDEXACCESS > SAL_CALL SfxBaseModel::getViewData() throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1666,7 +1593,7 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 /*N*/ void SAL_CALL SfxBaseModel::setViewData( const REFERENCE < XINDEXACCESS >& aData ) throw(::com::sun::star::uno::RuntimeException)
 /*N*/ {
 /*N*/ 	// object already disposed?
-/*N*/     ::vos::OGuard aGuard( Application::GetSolarMutex() );
+/*N*/     SolarMutexGuard aGuard;
 /*N*/ 	if ( impl_isDisposed() )
 /*N*/ 		throw DISPOSEDEXCEPTION();
 /*N*/
@@ -1709,3 +1636,5 @@ extern sal_Bool supportsMetaFileHandle_Impl();
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
