@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -50,7 +51,7 @@
 #include "insdlg.hxx"
 #include "bf_so3/outplace.hxx"
 #include <viscache.hxx>
-#include <vos/module.hxx>
+#include <osl/module.hxx>
 #include <sot/formats.hxx>
 #include <bf_svtools/filter.hxx>
 #include <comphelper/classids.hxx>
@@ -59,7 +60,6 @@
 #include <unotools/ucbstreamhelper.hxx>
 #include <bf_svtools/wmf.hxx>
 
-using namespace vos;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::datatransfer;
 
@@ -635,7 +635,7 @@ SvInPlaceObjectRef SvOutPlaceObject::InsertObject
     io.dwFlags=IOF_SELECTCREATENEW | IOF_DISABLELINK;
     io.clsid = rName.GetCLSID();
 
-    OModule aOleDlgLib;
+    osl::Module aOleDlgLib;
     if( !aOleDlgLib.load( String::CreateFromAscii( RTL_CONSTASCII_STRINGPARAM( "oledlg" ) ) ) )
         return &xRet;
 
@@ -1711,3 +1711,5 @@ void SvOutPlaceObject::DrawObject
     }
 }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
