@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -37,9 +38,7 @@
 #include <sot/storinfo.hxx>
 #include <sot/formats.hxx>
 
-#ifndef _DEBUG_HXX //autogen
 #include <tools/debug.hxx>
-#endif
 
 #include <unotools/ucbhelper.hxx>
 #include <unotools/tempfile.hxx>
@@ -1957,3 +1956,5 @@ void SvPersist::CleanUp( BOOL bRecurse)
     }
 }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
