@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,8 +31,6 @@
 
 #include <string.h>
 #include <stdio.h>
-#ifndef GCC
-#endif
 
 #include <bf_svtools/itempool.hxx>
 #include "whassert.hxx"
@@ -1082,3 +1081,5 @@ void SfxItemPool::SetFileFormatVersion( USHORT nFileFormatVersion )
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
