@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,13 +29,9 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 
 
-#ifndef TOOLS_INETMIME_HXX
 #include <tools/inetmime.hxx>
-#endif
 
-#ifndef _ADRPARSE_HXX
 #include <adrparse.hxx>
-#endif
 
 
 //============================================================================
@@ -773,3 +770,5 @@ SvAddressParser::~SvAddressParser()
 }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
