@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,10 +29,8 @@
 #define _SVX_USE_UNOGLOBALS_
 
 #ifndef SVX_LIGHT
-#ifndef _SOT_CLSIDS_HXX 
 #include <sot/clsids.hxx>
 #endif
-#endif
 
 /*
 */
@@ -47,21 +46,15 @@
 #include "svdopath.hxx"
 #include "svdomeas.hxx"
 
-#ifndef _E3D_EXTRUD3D_HXX
 #include <extrud3d.hxx>
-#endif
 
-#ifndef _E3D_LATHE3D_HXX
 #include <lathe3d.hxx>
-#endif
 #include <cube3d.hxx>
 #include <sphere3d.hxx>
 #include <polygn3d.hxx>
 
 namespace binfilter {
 
-using namespace ::vos;
-using namespace ::rtl;
 using namespace ::cppu;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -69,6 +62,8 @@ using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::drawing;
 
+using rtl::OUString;
+
 #define INTERFACE_TYPE( xint ) \
     ::getCppuType((const Reference< xint >*)0)
 
@@ -157,7 +152,7 @@ void SvxDrawPage::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
 void SAL_CALL SvxDrawPage::add( const Reference< drawing::XShape >& xShape )
     throw( uno::RuntimeException )
 {
-    OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     SvxShape* pShape = SvxShape::getImplementation( xShape );
 
@@ -190,7 +185,7 @@ void SAL_CALL SvxDrawPage::add( const Reference< drawing::XShape >& xShape )
 void SAL_CALL SvxDrawPage::remove( const Reference< drawing::XShape >& xShape )
     throw( uno::RuntimeException )
 {
-    OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     SvxShape* pShape = SvxShape::getImplementation( xShape );
 
@@ -230,7 +225,7 @@ sal_Int32 SAL_CALL SvxDrawPage::getCount()
 uno::Any SAL_CALL SvxDrawPage::getByIndex( sal_Int32 Index )
     throw( lang::IndexOutOfBoundsException, lang::WrappedTargetException, uno::RuntimeException)
 {
-    OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     if(pPage == NULL)
         throw uno::RuntimeException();
@@ -316,7 +311,7 @@ void SvxDrawPage::_SelectObjectInView( const Reference< drawing::XShape > & xSha
 Reference< drawing::XShapeGroup > SAL_CALL SvxDrawPage::group( const Reference< drawing::XShapes >& xShapes )
     throw( uno::RuntimeException )
 {
-    OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     DBG_ASSERT(pPage,"SdrPage ist NULL! [CL]");
     DBG_ASSERT(pView, "SdrView ist NULL! [CL]");
@@ -352,7 +347,7 @@ Reference< drawing::XShapeGroup > SAL_CALL SvxDrawPage::group( const Reference<
 void SAL_CALL SvxDrawPage::ungroup( const Reference< drawing::XShapeGroup >& aGroup )
     throw( uno::RuntimeException )
 {
-    OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     DBG_ASSERT(pPage,"SdrPage ist NULL! [CL]");
     DBG_ASSERT(pView, "SdrView ist NULL! [CL]");
@@ -478,7 +473,7 @@ SdrObject *SvxDrawPage::_CreateSdrObject( const Reference< drawing::XShape > & x
 //----------------------------------------------------------------------
 void SvxDrawPage::GetTypeAndInventor( sal_uInt16& rType, sal_uInt32& rInventor, const OUString& aName ) const throw()
 {
-    sal_uInt32 nTempType = aSdrShapeIdentifierMap.getId( aName );
+    sal_uInt32 nTempType = UHashMap::getId( aName );
 
     if(nTempType & E3D_INVENTOR_FLAG)
     {
@@ -778,3 +773,5 @@ SvxShape* CreateSvxShapeByTypeAndInventor( sal_uInt16 nType, sal_uInt32 nInvento
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
