@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -34,16 +35,12 @@
 #include "cntfrm.hxx"
 #include "node.hxx"
 
-#ifndef _HORIORNT_HXX
 #include <horiornt.hxx>
-#endif
 
 #include "doc.hxx"
 #include "frmtool.hxx"
 
-#ifndef _FRMFMT_HXX //autogen
 #include <frmfmt.hxx>
-#endif
 #include "tabfrm.hxx"
 #include "sectfrm.hxx"
 #include "flyfrms.hxx"
@@ -1135,3 +1132,5 @@ SwCntntFrm *SwPageFrm::FindLastBodyCntnt()
 
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
