@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,21 +31,15 @@
 #pragma hdrstop
 #endif
 
-#ifndef _HORIORNT_HXX
 #include <horiornt.hxx>
-#endif
 
 #include "doc.hxx"
 
-#ifndef _ERRHDL_HXX
 #include <errhdl.hxx>
-#endif
 
 #include "pam.hxx"
 
-#ifndef _FMTFSIZE_HXX //autogen
 #include <fmtfsize.hxx>
-#endif
 #include "rdswg.hxx"
 #include "swgpar.hxx"
 #include "ndtxt.hxx"
@@ -663,3 +658,5 @@ USHORT SwSwgReader::RegisterSection( const SwNodeIndex& rIdx, USHORT nId )
 }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
