@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -32,12 +33,8 @@
 
 #include <stdlib.h>  // strtod()
 
-#ifndef _LINKMGR_HXX //autogen
 #include <bf_so3/linkmgr.hxx>
-#endif
-#ifndef _DATETIME_HXX
 #include <tools/datetime.hxx>
-#endif
 
 #include "doc.hxx"
 #include "rdswg.hxx"
@@ -774,3 +771,5 @@ SwFieldType* SwSwgReader::InFieldType()
 }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
