@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,41 +26,27 @@
  *
  ************************************************************************/
 
-#ifndef _TOOLS_DEBUG_HXX 
 #include <tools/debug.hxx>
-#endif
 
 
 #include <list>
 
 
 
-#ifndef _XMLOFF_XMLNMSPE_HXX
 #include "xmlnmspe.hxx"
-#endif
 
 
-#ifndef _XIMPSTYLE_HXX
 #include "ximpstyl.hxx"
-#endif
 
 
-#ifndef _SDPROPLS_HXX
 #include "sdpropls.hxx"
-#endif
 
 
-#ifndef _XIMP3DSCENE_HXX
 #include "ximp3dscene.hxx"
-#endif
 
-#ifndef _XIMP3DOBJECT_HXX
 #include "ximp3dobject.hxx"
-#endif
 
-#ifndef _XIMPGROUP_HXX
 #include "ximpgrp.hxx"
-#endif
 
 #include <map>
 #include <vector>
@@ -200,7 +187,7 @@ XMLShapeImportHelper::XMLShapeImportHelper(
 
 /*
     // chain form attributes
-    const UniReference< SvXMLImportPropertyMapper> xFormMapper( rImporter.GetFormImport()->getStylePropertyMapper().getBodyPtr() );
+    const UniReference< SvXMLImportPropertyMapper> xFormMapper( rImporter.GetFormImport()->getStylePropertyMapper().get() );
     mpPropertySetMapper->ChainImportMapper(xFormMapper);
 */
 
@@ -1101,3 +1088,5 @@ sal_Bool XMLShapeImportHelper::IsPresentationShapesSupported()
 }
 
 }//end of namespace binfilter
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
