@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -26,33 +27,21 @@
  ************************************************************************/
 
 #include <tools/inetdef.hxx>
-#ifndef _URLOBJ_HXX
 #include <tools/urlobj.hxx>
-#endif
 #include <unotools/configmgr.hxx>
 
 #include "xmlmetae.hxx"
 
 
-#ifndef _TOOLS_TIME_HXX
 #include <tools/time.hxx>
-#endif
 
-#ifndef _UTL_BOOTSTRAP_HXX
 #include <unotools/bootstrap.hxx>
-#endif
 
-#ifndef _XMLOFF_XMLNMSPE_HXX
 #include "xmlnmspe.hxx"
-#endif
 
-#ifndef _XMLOFF_XMLEXP_HXX
 #include "xmlexp.hxx"
-#endif
 
-#ifndef _COM_SUN_STAR_DOCUMENT_XDOCUMENTINFOSUPPLIER_HPP_
 #include <com/sun/star/document/XDocumentInfoSupplier.hpp>
-#endif
 #include "bf_so3/staticbaseurl.hxx"
 namespace binfilter {
 
@@ -233,22 +222,19 @@ rtl::OUString lcl_GetProductName()
     //  get the correct product name from the configuration
 
     ::rtl::OUStringBuffer aName;
-    utl::ConfigManager* pMgr = utl::ConfigManager::GetConfigManager();
-    if (pMgr)
-    {
-        ::rtl::OUString aValue;
-        uno::Any aAny = pMgr->GetDirectConfigProperty(utl::ConfigManager::PRODUCTNAME);
-        if ( (aAny >>= aValue) && aValue.getLength() )
-            aName.append( aValue ).append( (sal_Unicode)' ' );
+    utl::ConfigManager& rMgr = utl::ConfigManager::GetConfigManager();
+    ::rtl::OUString aValue;
+    uno::Any aAny = rMgr.GetDirectConfigProperty(utl::ConfigManager::PRODUCTNAME);
+    if ( (aAny >>= aValue) && aValue.getLength() )
+        aName.append( aValue ).append( (sal_Unicode)' ' );
 
-        aAny = pMgr->GetDirectConfigProperty(utl::ConfigManager::PRODUCTVERSION);
-        if ( (aAny >>= aValue) && aValue.getLength() )
-            aName.append( aValue ).append( (sal_Unicode)' ' );
+    aAny = rMgr.GetDirectConfigProperty(utl::ConfigManager::PRODUCTVERSION);
+    if ( (aAny >>= aValue) && aValue.getLength() )
+        aName.append( aValue ).append( (sal_Unicode)' ' );
 
-        aAny = pMgr->GetDirectConfigProperty(utl::ConfigManager::PRODUCTEXTENSION);
-        if ( (aAny >>= aValue) && aValue.getLength() )
-            aName.append( aValue ).append( (sal_Unicode)' ' );
-    }
+    aAny = rMgr.GetDirectConfigProperty(utl::ConfigManager::PRODUCTEXTENSION);
+    if ( (aAny >>= aValue) && aValue.getLength() )
+        aName.append( aValue ).append( (sal_Unicode)' ' );
     aName.append( (sal_Unicode)'(' );
     aName.appendAscii( TOOLS_INETDEF_OS );
     aName.append( (sal_Unicode)')' );
@@ -506,3 +492,5 @@ void SfxXMLMetaExport::Export()
 
 
 }//end of namespace binfilter
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
