@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,17 +31,11 @@
 
 #include <bf_svtools/zformat.hxx>
 #include <bf_svtools/numuno.hxx>
-#ifndef INCLUDED_SVTOOLS_NFSYMBOL_HXX
 #include <bf_svtools/nfsymbol.hxx>
-#endif
 #include <i18npool/mslangid.hxx>
 #include <tools/debug.hxx>
 #include <rtl/math.hxx>
 
-// #110680#
-//#include <comphelper/processfactory.hxx>
-
-
 #include "xmlnmspe.hxx"
 #include "xmluconv.hxx"
 #include "xmlnumfi.hxx"		// SvXMLNumFmtDefaults
@@ -49,9 +44,7 @@
 #include <bf_svtools/svstdarr.hxx>
 
 
-#ifndef _XMLOFF_XMLEXP_HXX
 #include "xmlexp.hxx"
-#endif
 
 #include <set>
 namespace binfilter {
@@ -1788,3 +1781,5 @@ sal_uInt32 SvXMLNumFmtExport::ForceSystemLanguage( sal_uInt32 nKey )
     return nRet;
 }
 }//end of namespace binfilter
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
