@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -35,9 +36,7 @@
 #include <com/sun/star/document/XExtendedFilterDetection.hpp>
 #include <com/sun/star/util/XURLTransformer.hpp>
 
-#ifndef _COM_SUN_STAR_IO_XINPUSTREAM_HPP_
 #include <com/sun/star/io/XInputStream.hpp>
-#endif
 #include <com/sun/star/io/XSeekable.hpp>
 #include <com/sun/star/task/XInteractionHandler.hpp>
 #include <tools/wldcrd.hxx>
@@ -1255,3 +1254,5 @@ css::uno::Reference< css::uno::XInterface > SAL_CALL TypeDetection::impl_createI
 
     } // namespace config
 } // namespace filter
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
