@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,9 +32,7 @@
 #include <com/sun/star/container/XNameAccess.hpp>
 #include <com/sun/star/util/XFlushable.hpp>
 
-#ifndef _COM_SUN_STAR_BEANS_NAMEDVALUE_HPP_
 #include <com/sun/star/beans/PropertyValue.hpp>
-#endif
 
 #include "com/sun/star/ui/dialogs/TemplateDescription.hpp"
 #include <tools/urlobj.hxx>
@@ -1797,3 +1796,5 @@ bool createDirectory( OUString& rURL )
 
     return true;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
