@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -56,6 +57,8 @@
 #include <com/sun/star/text/XTextContent.hpp>
 #include <com/sun/star/text/XTextField.hpp>
 #include <com/sun/star/text/XTextRange.hpp>
+#include <com/sun/star/chart2/XChartDocument.hpp>
+#include <com/sun/star/frame/XModel.hpp>
 #include <tools/stream.hxx>
 #include <tools/string.hxx>
 #include <vcl/cvtgrf.hxx>
@@ -70,6 +73,7 @@
 #include <svx/svdoashp.hxx>
 #include <editeng/svxenum.hxx>
 #include <svx/unoapi.hxx>
+#include <oox/export/chartexport.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -89,6 +93,10 @@ using ::com::sun::star::text::XText;
 using ::com::sun::star::text::XTextContent;
 using ::com::sun::star::text::XTextField;
 using ::com::sun::star::text::XTextRange;
+using ::oox::core::XmlFilterBase;
+using ::com::sun::star::chart2::XChartDocument;
+using ::com::sun::star::frame::XModel;
+using ::oox::core::XmlFilterBase;
 using ::rtl::OString;
 using ::rtl::OStringBuffer;
 using ::rtl::OUString;
@@ -357,14 +365,15 @@ namespace oox { namespace drawingml {
     if ( GETA(propName) ) \
         mAny >>= variable;
 
-ShapeExport::ShapeExport( sal_Int32 nXmlNamespace, FSHelperPtr pFS, ::oox::core::XmlFilterBase* pFB, DocumentType eDocumentType )
+ShapeExport::ShapeExport( sal_Int32 nXmlNamespace, FSHelperPtr pFS, ShapeHashMap* pShapeMap, XmlFilterBase* pFB, DocumentType eDocumentType )
     : DrawingML( pFS, pFB, eDocumentType )
-    , mnXmlNamespace( nXmlNamespace )
     , mnShapeIdMax( 1 )
     , mnPictureIdMax( 1 )
+    , mnXmlNamespace( nXmlNamespace )
     , maFraction( 1, 576 )
     , maMapModeSrc( MAP_100TH_MM )
     , maMapModeDest( MAP_INCH, Point(), maFraction, maFraction )
+    , mpShapeMap( pShapeMap ? pShapeMap : &maShapeMap )
 {
 }
 
@@ -422,7 +431,7 @@ ShapeExport& ShapeExport::WriteBezierShape( Reference< XShape > xShape, sal_Bool
 
     // visual shape properties
     pFS->startElementNS( mnXmlNamespace, XML_spPr, FSEND );
-    WriteTransformation( aRect );
+    WriteTransformation( aRect, XML_a );
     WritePolyPolygon( aPolyPolygon );
     Reference< XPropertySet > xProps( xShape, UNO_QUERY );
     if( xProps.is() ) {
@@ -503,7 +512,7 @@ ShapeExport& ShapeExport::WriteCustomShape( Reference< XShape > xShape )
 
     // visual shape properties
     pFS->startElementNS( mnXmlNamespace, XML_spPr, FSEND );
-    WriteShapeTransformation( xShape );
+    WriteShapeTransformation( xShape, XML_a );
     if( nAdjustmentValuesIndex != -1 )
         WritePresetShape( sPresetShape, eShapeType, bPredefinedHandlesUsed, nAdjustmentsWhichNeedsToBeConverted, aGeometrySeq[ nAdjustmentValuesIndex ] );
     else
@@ -546,7 +555,7 @@ ShapeExport& ShapeExport::WriteEllipseShape( Reference< XShape > xShape )
 
     // visual shape properties
     pFS->startElementNS( mnXmlNamespace, XML_spPr, FSEND );
-    WriteShapeTransformation( xShape );
+    WriteShapeTransformation( xShape, XML_a );
     WritePresetShape( "ellipse" );
     Reference< XPropertySet > xProps( xShape, UNO_QUERY );
     if( xProps.is() )
@@ -564,39 +573,6 @@ ShapeExport& ShapeExport::WriteEllipseShape( Reference< XShape > xShape )
     return *this;
 }
 
-ShapeExport& ShapeExport::WriteFill( Reference< XPropertySet > xPropSet )
-{
-    FillStyle aFillStyle( FillStyle_NONE );
-    xPropSet->getPropertyValue( S( "FillStyle" ) ) >>= aFillStyle;
-
-    if( aFillStyle == FillStyle_BITMAP )
-    {
-        //DBG(printf ("FillStyle_BITMAP properties\n"));
-        //DBG(dump_pset(rXPropSet));
-    }
-
-    if( aFillStyle == FillStyle_NONE ||
-        aFillStyle == FillStyle_HATCH ) 
-        return *this;
-    
-    switch( aFillStyle )
-    {
-    case ::com::sun::star::drawing::FillStyle_SOLID :
-        WriteSolidFill( xPropSet );
-        break;
-    case ::com::sun::star::drawing::FillStyle_GRADIENT :
-        WriteGradientFill( xPropSet );
-        break;
-    case ::com::sun::star::drawing::FillStyle_BITMAP :
-        WriteBlipFill( xPropSet, S( "FillBitmapURL" ) );
-        break;
-    default:
-        ;
-    }
-
-    return *this;
-}
-
 ShapeExport& ShapeExport::WriteGraphicObjectShape( Reference< XShape > xShape )
 {
     DBG(printf("write graphic object shape\n"));
@@ -647,7 +623,7 @@ ShapeExport& ShapeExport::WriteGraphicObjectShape( Reference< XShape > xShape )
 
     pFS->startElementNS( mnXmlNamespace, XML_blipFill, FSEND );
     
-    WriteBlip( sGraphicURL );
+    WriteBlip( xShapeProps, sGraphicURL );
 
     bool bStretch = false;
     if( ( xShapeProps->getPropertyValue( S( "FillBitmapStretch" ) ) >>= bStretch ) && bStretch )
@@ -659,7 +635,7 @@ ShapeExport& ShapeExport::WriteGraphicObjectShape( Reference< XShape > xShape )
 
     // visual shape properties
     pFS->startElementNS( mnXmlNamespace, XML_spPr, FSEND );
-    WriteShapeTransformation( xShape );
+    WriteShapeTransformation( xShape, XML_a );
     WritePresetShape( "rect" );
     pFS->endElementNS( mnXmlNamespace, XML_spPr );
 
@@ -791,7 +767,7 @@ ShapeExport& ShapeExport::WriteLineShape( Reference< XShape > xShape )
 
     // visual shape properties
     pFS->startElementNS( mnXmlNamespace, XML_spPr, FSEND );
-    WriteShapeTransformation( xShape, bFlipH, bFlipV );
+    WriteShapeTransformation( xShape, XML_a, bFlipH, bFlipV );
     WritePresetShape( "line" );
     Reference< XPropertySet > xShapeProps( xShape, UNO_QUERY );
     if( xShapeProps.is() )
@@ -855,7 +831,7 @@ ShapeExport& ShapeExport::WriteRectangleShape( Reference< XShape > xShape )
 
     // visual shape properties
     pFS->startElementNS( mnXmlNamespace, XML_spPr, FSEND );
-    WriteShapeTransformation( xShape );
+    WriteShapeTransformation( xShape, XML_a );
     WritePresetShape( "rect" );
     Reference< XPropertySet > xProps( xShape, UNO_QUERY );
     if( xProps.is() )
@@ -893,6 +869,7 @@ static const NameToConvertMapType& lcl_GetConverters()
     shape_converters[ "com.sun.star.drawing.LineShape" ]                = &ShapeExport::WriteLineShape;
     shape_converters[ "com.sun.star.drawing.OpenBezierShape" ]          = &ShapeExport::WriteOpenBezierShape;
     shape_converters[ "com.sun.star.drawing.RectangleShape" ]           = &ShapeExport::WriteRectangleShape;
+    shape_converters[ "com.sun.star.drawing.OLE2Shape" ]                = &ShapeExport::WriteOLE2Shape;
     shape_converters[ "com.sun.star.drawing.TextShape" ]                = &ShapeExport::WriteTextShape;
     shape_converters[ "com.sun.star.presentation.DateTimeShape" ]       = &ShapeExport::WriteTextShape;
     shape_converters[ "com.sun.star.presentation.FooterShape" ]         = &ShapeExport::WriteTextShape;
@@ -950,7 +927,7 @@ ShapeExport& ShapeExport::WriteTextShape( Reference< XShape > xShape )
 
     // visual shape properties
     pFS->startElementNS( mnXmlNamespace, XML_spPr, FSEND );
-    WriteShapeTransformation( xShape );
+    WriteShapeTransformation( xShape, XML_a );
     WritePresetShape( "rect" );
     WriteBlipFill( Reference< XPropertySet >(xShape, UNO_QUERY ), S( "GraphicURL" ) );
     pFS->endElementNS( mnXmlNamespace, XML_spPr );
@@ -962,6 +939,25 @@ ShapeExport& ShapeExport::WriteTextShape( Reference< XShape > xShape )
     return *this;
 }
 
+ShapeExport& ShapeExport::WriteOLE2Shape( Reference< XShape > xShape )
+{
+    Reference< XPropertySet > xPropSet( xShape, UNO_QUERY );
+    if( xPropSet.is() && GetProperty( xPropSet, S("Model") ) )
+    {
+        Reference< XChartDocument > xChartDoc;
+        mAny >>= xChartDoc;
+        if( xChartDoc.is() )
+        {
+            //export the chart
+            Reference< XModel > xModel( xChartDoc, UNO_QUERY );
+            ChartExport aChartExport( mnXmlNamespace, GetFS(), xModel, GetFB(), GetDocumentType() );
+            static sal_Int32 nChartCount = 0;
+            aChartExport.WriteChartObj( xShape, ++nChartCount );
+        }
+    }
+    return *this;
+}
+
 ShapeExport& ShapeExport::WriteUnknownShape( Reference< XShape > )
 {
     // Override this method to do something useful.
@@ -975,21 +971,39 @@ size_t ShapeExport::ShapeHash::operator()( const ::com::sun::star::uno::Referenc
 
 sal_Int32 ShapeExport::GetNewShapeID( const Reference< XShape > rXShape )
 {
-    sal_Int32 nID = GetFB()->GetUniqueId();
+    return GetNewShapeID( rXShape, GetFB() );
+}
 
-    maShapeMap[ rXShape ] = nID;
+sal_Int32 ShapeExport::GetNewShapeID( const Reference< XShape > rXShape, XmlFilterBase* pFB )
+{
+    if( !rXShape.is() )
+        return -1;
+
+    sal_Int32 nID = pFB->GetUniqueId();
+
+    (*mpShapeMap)[ rXShape ] = nID;
 
     return nID;
 }
 
 sal_Int32 ShapeExport::GetShapeID( const Reference< XShape > rXShape )
 {
-    ShapeHashMap::const_iterator aIter = maShapeMap.find( rXShape );
+    return GetShapeID( rXShape, mpShapeMap );
+}
 
-    if( aIter == maShapeMap.end() )
+sal_Int32 ShapeExport::GetShapeID( const Reference< XShape > rXShape, ShapeHashMap* pShapeMap )
+{
+    if( !rXShape.is() )
+        return -1;
+
+    ShapeHashMap::const_iterator aIter = pShapeMap->find( rXShape );
+
+    if( aIter == pShapeMap->end() )
         return -1;
 
     return aIter->second;
 }
 
 } }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
