@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -29,6 +30,7 @@
 #include <StyleSheetTable.hxx>
 #include <com/sun/star/table/TableBorderDistances.hpp>
 #include <com/sun/star/table/TableBorder.hpp>
+#include <com/sun/star/table/BorderLine2.hpp>
 #include <com/sun/star/text/HoriOrientation.hpp>
 #include <dmapperLoggers.hxx>
 
@@ -65,7 +67,7 @@ static void  lcl_printProperties( PropertyMapPtr pProps )
             rtl::OString aOStr(aOUStr.getStr(), aOUStr.getLength(),  RTL_TEXTENCODING_ASCII_US );
             clog << aOStr.getStr();
 
-            table::BorderLine aLine;
+            table::BorderLine2 aLine;
             sal_Int32 nColor; 
             if ( aMapIter->second >>= aLine )
             {
@@ -496,13 +498,6 @@ TableStyleSheetEntry * DomainMapperTableHandler::endTableGetTableStyle(TableInfo
         if( aRepeatIter == m_aTableProperties->end() )
             m_aTableProperties->Insert( PROP_HEADER_ROW_COUNT, false, uno::makeAny( (sal_Int32)0 ));
         
-        // Remove the PROP_HEADER_ROW_COUNT from the table default to avoid
-        // propagating it to the cells
-        PropertyMap::iterator aDefaultRepeatIt =
-        rInfo.pTableDefaults->find( PropertyDefinition( PROP_HEADER_ROW_COUNT, false ) );
-        if ( aDefaultRepeatIt != rInfo.pTableDefaults->end( ) )
-            rInfo.pTableDefaults->erase( aDefaultRepeatIt );
-        
         rInfo.aTableProperties = m_aTableProperties->GetPropertyValues();
         
 #ifdef DEBUG_DOMAINMAPPER
@@ -592,7 +587,14 @@ CellPropertyValuesSeq_t DomainMapperTableHandler::endTableGetCellProperties(Tabl
                     PropertyMapPtr pStyleProps = rInfo.pTableStyle->GetProperties( nCellStyleMask + nRowStyleMask );
                     pAllCellProps->insert( pStyleProps );
                 }
-                
+
+                // Remove properties from style/row that aren't allowed in cells
+                const PropertyMap::iterator aDefaultRepeatIt =
+                    pAllCellProps->find(
+                        PropertyDefinition( PROP_HEADER_ROW_COUNT, false ) );
+                if ( aDefaultRepeatIt != pAllCellProps->end( ) )
+                    pAllCellProps->erase( aDefaultRepeatIt );
+
                 // Then add the cell properties
                 pAllCellProps->insert( *aCellIterator );
                 aCellIterator->get( )->swap( *pAllCellProps.get( ) );
@@ -844,3 +846,5 @@ void DomainMapperTableHandler::endCell(const Handle_t & end)
 }
 
 }}
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
